package
Version:
v2.0.2
Opens a new window with list of versions in this module.
Published: Jun 8, 2025
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type JobConf struct {
Context interface{}
JobFunc interface{}
QueueName string
JobName string
Priority uint
Concurrency uint
}
type Queue struct {
Names string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.